@@ -1,9 +1,25 @@
 from __future__ import unicode_literals
-
+import sys
 import copy
 import datetime
 
-VERSION = "0.0.12"
+PYTHON3 = True
+if sys.version_info[0] < 3:
+    PYTHON3 = False
+
+VERSION = "0.0.13"
+
+def is_map(obj):
+    return PYTHON3 and isinstance(obj, map)
+
+def ensureUtf(s):
+    try:
+        if isinstance(s, str):
+            return s
+        else:
+            return s.encode('utf8', 'ignore')
+    except:
+        return str(s)
 
 
 class classproperty(object):
@@ -122,7 +138,7 @@ class Q(QMixin):
 
     def _get_value(self, value):
         if isinstance(value, int) or isinstance(value, float):
-            return unicode(value)
+            return ensureUtf(value)
 
         if isinstance(value, datetime.datetime):
             return "'%s'" % value.strftime(self.datetime_format)
@@ -130,11 +146,11 @@ class Q(QMixin):
         if isinstance(value, datetime.date):
             return "'%s'" % value.strftime(self.date_format)
 
-        if isinstance(value, list) or isinstance(value, set):
+        if isinstance(value, list) or isinstance(value, set) or is_map(value):
             return ", ".join([self._get_value(item) for item in value])
 
         if isinstance(value, F) or isinstance(value, QMixin) or isinstance(value, SQLQuery):
-            return unicode(value)
+            return ensureUtf(value)
 
         return "'%s'" % value
 
@@ -218,6 +234,7 @@ class SQLQuery(object):
         self._extra = {}
         self._limits = None
         self._sql = sql
+        self._nolock = False
 
     def has_filters(self,):
         return self._order_by or self._group_by or self._joins\
@@ -244,6 +261,11 @@ class SQLQuery(object):
         clone._values = list(args)
         return clone
 
+    def with_nolock(self, enabled=True):
+        clone = self._clone()
+        clone._nolock = enabled
+        return clone
+
     def filter(self, *args, **kwargs):
         clone = self._clone()
         clone._filters &= self._q(*args, **kwargs)
@@ -304,7 +326,7 @@ class SQLCompiler(object):
         return self._table
 
     def get_where(self):
-        filters = unicode(self._filters & ~self._excludes)
+        filters = ensureUtf(self._filters & ~self._excludes)
         extra_where = self.get_extra_where()
 
         if filters or extra_where:
@@ -338,6 +360,11 @@ class SQLCompiler(object):
         if self._joins:
             return "  ".join(self._joins)
 
+    def get_nolock(self,):
+        if self._nolock:
+            return " WITH (NOLOCK)"
+        return ""
+
     def get_limits(self,):
         if self._limits and self.sql_mode != "SQL_SERVER":
             offset = self._limits.start
@@ -362,7 +389,8 @@ class SQLCompiler(object):
             table = self.get_table()
 
         sql = ["SELECT", self.get_top(), self.get_columns(),
-               "FROM", table, "WITH (NOLOCK)",
+               "FROM", table,
+               self.get_nolock(),
                self.get_joins(), self.get_where(),
                self.get_group_by(), self.get_order_by(),
                self.get_limits()]
@@ -381,14 +409,15 @@ class SQLCompiler(object):
 
             return ["SELECT * FROM (", "SELECT", ",".join([paginate, self.get_columns()]),
                     "FROM", table,
-                    self.get_joins(), self.get_where(),
+                    self.get_joins(),
+                    self.get_where(),
                     self.get_group_by(),
                     self.get_limits(), ") as tbl_paginated WHERE ", conds]
 
         return sql
 
     def _compile(self):
-        return " ".join([unicode(item) for item in self.get_sql_structure() if item])
+        return " ".join([ensureUtf(item) for item in self.get_sql_structure() if item])
 
     def __repr__(self):
         return self._compile()
